%% CONFIG_ROTFLEX
%
% Find the stiffness parameters of the SRV02 Rotary Flexible Joint plant.
%
% ************************************************************************
% Input parameters:
% SPRING            Spring type used (default is 2, set to 1, 2 or 3)
% HUB_POSITION      Position of spring on hub ('A', 'B' or 'C')
% ARM_POSITION      Position of Spring Anchor on Arm, set to 1, 2 or 3
%
% ************************************************************************
% Output parameters:
% Ks            Stiffness of flexible joint (kg.m^2/s)
%
% Copyright (C) 2011 Quanser Consulting Inc.
% Quanser Consulting Inc.

function [Ks] = config_rotflex_stiffness(SPRING, HUB_POSITION, ARM_POSITION)
%
%% Spring Constants
% spring 1 used, LEAST STIFFNESS
aL(1) = 0.0254*1.0;
aFr(1) = 0.85;
aK(1) = 0.22*1000*.85;
% spring used E0240-026-1250 MEDIUM STIFFNESS (DEFAULT)
aL(2) = 0.0254*1.25;
aFr(2) = 1.33;
aK(2) = 0.368*1000*.85;
% spring used E0240-029-1250 STIFFEST
aL(3) = 0.0254*1.25;
aFr(3) = 1.78;
aK(3) = 0.665*1000*.85;
%
%% Hub/Arm Position Constants
% POSITION ON HUB (BASE)
ad(1) = 0.0254*1.25; % from hinge to spring insertion on plate, along arm
ad(2) = 0.0254*1.00; % from hinge to spring insertion on plate, along arm
ad(3) = 0.0254*0.75; % from hinge to spring insertion on plate, along arm
%
% POSITION ON ARM (LINK)
aR(1) = 0.0254*4.0; % from hinge to spring insertion on arm
aR(2) = 0.0254*3.5; % from hinge to spring insertion on arm
aR(3) = 0.0254*3.0; % from hinge to spring insertion on arm
%
% Fixed distance
r = 0.0254*1.25; % Fixed distance

%% Sprint Stiffness
L = aL(SPRING);
Fr = aFr (SPRING);
K = aK(SPRING);
%
% Setting to current hub position
if strcmp (HUB_POSITION, 'A')
    d = ad(1);
elseif strcmp (HUB_POSITION, 'B')
    d = ad(2);
elseif strcmp (HUB_POSITION, 'C')
    d = ad(3);
end
% Setting to current arm position
R = aR(ARM_POSITION);
D = r^2+(R-d)^2;

